==> monitor-0.1.tar.gz: monitor/libraries/user_agent.php <==
<?php
	$browsers = array(
		"Firefox 4",
		"Firefox 3",
		"Firefox 2",
		"Firefox/4" => "Firefox 4",
		"Firefox/3" => "Firefox 3",
		"Firefox/2" => "Firefox 2",
		"Iceweasel/4" => "Firefox 4",
		"Iceweasel/3" => "Firefox 3",
		"Iceweasel/2" => "Firefox 2",
		"Camino",
		"Thunderbird",
		"Chrome/4" => "Chrome 4",
		"Chrome/3" => "Chrome 3",
		"Chrome/2" => "Chrome 2",
		"Chrome 4",
		"Chrome 3",
		"Chrome 2",
		"Safari",
		"Opera",
		"Konqueror",
		"Googlebot" => "Google searchbot",
		"Feedfetcher-Google" => "Google searchbot",
		"msnbot" => "MSN searchbot",
		"Yahoo! Slurp" => "Yahoo searchbot",
		"Yandex" => "Yandex searchbot",
		"Twiceler" => "Twiceler searchbot",
		"Wget",
		"libfetch",
		"robot" => "searchbot",
		"spider" => "searchbot",
		"crawler" => "searchbot",
		"robot" => "searchbot",
		"AppleWebKit" => "WebKit based browser",
		"Gecko" => "Gecko based browser",
		"MSIE 9" => "Internet Explorer 9",
		"MSIE 8" => "Internet Explorer 8",
		"MSIE 7" => "Internet Explorer 7",
		"MSIE 6" => "Internet Explorer 6",
		"MSIE 5" => "Internet Explorer 5");

	$oses = array(
		"Windows NT 6.1" => "Windows 7",
		"Windows NT 6.0" => "Windows Vista",
		"Windows NT 5.2" => "Windows Server 2003",
		"Windows NT 5.1" => "Windows XP",
		"Windows NT 5.0" => "Windows 2000",
		"Windows NT 4.0" => "Windows NT",
		"Windows 98",
		"Windows 95",
		"Linux",
		"FreeBSD",
		"NetBSD",
		"OpenBSD",
		"Macintosh" => "Mac PowerPC",
		"PowerPC " => "Mac PowerPC",
		"iPhone",
		"Nokia",
		"Windows CE",
		"Mac OS X 10.6" => "MacOS X 10.6",
		"Mac OS X 10.5" => "MacOS X 10.5",
		"Mac OS X 10.4" => "MacOS X 10.4",
		"Mac OS X 10.3" => "MacOS X 10.3",
		"Mac OS X 10_6" => "MacOS X 10.6",
		"Mac OS X 10_5" => "MacOS X 10.5",
		"Mac OS X 10_4" => "MacOS X 10.4",
		"Mac OS X 10_3" => "MacOS X 10.3",
		"Mac OS X" => "MacOS X",
		"SunOS",
		"Googlebot" => "searchbot",
		"Feedfetcher-Google" => "searchbot",
		"msnbot" => "searchbot",
		"Yahoo! Slurp" => "searchbot",
		"Yandex" => "searchbot",
		"Twiceler" => "searchbot",
		"robot" => "searchbot",
		"spider" => "searchbot",
		"crawler" => "searchbot",
		"robot" => "searchbot");
	
	function find_str($user_agent, $list) {
		$pos = false;
		foreach ($list as $key => $value) {
			if (($pos = strpos($user_agent, $key)) !== false) {
				break;
			}
		}

		if ($pos === false) {
			return "Other";
		}

		return $value;
	}

	function guess_browser($user_agent) {
		global $browser_list;

		return find_str($user_agent, $browser_list);
	}

	function guess_os($user_agent) {
		global $os_list;

		return find_str($user_agent, $os_list);
	}

	function ua_list($list) {
		$result = array();

		foreach ($list as $key => $value) {
			if (is_int($key)) {
				$result[$value] = $value;
			} else {
				$result[$key] = $value;
			}
		}

		return $result;
	}

	$browser_list = ua_list($browsers);
	$os_list = ua_list($oses);
?>

==> monitor-0.4.tar.gz: monitor/libraries/user_agent.php <==
<?php
	$browsers = array(
		"Firefox ?",
		"Firefox/?" => "Firefox",
		"Iceweasel/?" => "Firefox",
		"Camino",
		"Thunderbird",
		"Chrome/?" => "Chrome",
		"Chrome ?",
		"Safari",
		"Opera",
		"Konqueror",
		"Googlebot" => "Google searchbot",
		"Feedfetcher-Google" => "Google searchbot",
		"msnbot" => "MSN searchbot",
		"Yahoo! Slurp" => "Yahoo searchbot",
		"Yandex" => "Yandex searchbot",
		"Twiceler" => "Twiceler searchbot",
		"Wget",
		"libfetch",
		"robot" => "searchbot",
		"spider" => "searchbot",
		"crawler" => "searchbot",
		"robot" => "searchbot",
		"AppleWebKit" => "WebKit based browser",
		"Gecko" => "Gecko based browser",
		"MSIE ?" => "Internet Explorer");

	$oses = array(
		"Windows NT 6.2" => "Windows 8",
		"Windows NT 6.1" => "Windows 7",
		"Windows NT 6.0" => "Windows Vista",
		"Windows NT 5.2" => "Windows Server 2003",
		"Windows NT 5.1" => "Windows XP",
		"Windows NT 5.0" => "Windows 2000",
		"Windows NT 4.0" => "Windows NT",
		"Windows 98",
		"Windows 95",
		"Linux",
		"FreeBSD",
		"NetBSD",
		"OpenBSD",
		"Macintosh" => "Mac PowerPC",
		"PowerPC " => "Mac PowerPC",
		"iPhone",
		"Nokia",
		"Windows CE",
		"Mac OS X ?" => "MacOS X",
		"Mac OS X" => "MacOS X",
		"SunOS",
		"Googlebot" => "searchbot",
		"Feedfetcher-Google" => "searchbot",
		"msnbot" => "searchbot",
		"Yahoo! Slurp" => "searchbot",
		"Yandex" => "searchbot",
		"Twiceler" => "searchbot",
		"robot" => "searchbot",
		"spider" => "searchbot",
		"crawler" => "searchbot",
		"robot" => "searchbot");
	
	function find_str($user_agent, $list) {
		$pos = false;
		foreach ($list as $key => $value) {
			$seek_version = substr($key, -1) == "?";
			if ($seek_version) {
				$key = substr($key, 0, -1);
			}

			if (($pos = strpos($user_agent, $key)) !== false) {
				break;
			}
		}

		if ($pos === false) {
			return "Other";
		}

		if ($seek_version) {
			$rest = substr($user_agent, $pos + strlen($key));
			$rest = str_replace(";", " ", $rest);
			list($version) = explode(" ", $rest, 2);
			list($version) = explode(".", $version, 2);

			if (is_numeric($version)) {
				$value .= " ".$version;
			}
		}

		return $value;
	}

	function guess_browser($user_agent) {
		global $browser_list;

		return find_str($user_agent, $browser_list);
	}

	function guess_os($user_agent) {
		global $os_list;

		return find_str($user_agent, $os_list);
	}

	function ua_list($list) {
		$result = array();

		foreach ($list as $key => $value) {
			if (is_int($key)) {
				$result[$value] = rtrim(str_replace("?", "", $value));
			} else {
				$result[$key] = $value;
			}
		}

		return $result;
	}

	$browser_list = ua_list($browsers);
	$os_list = ua_list($oses);
?>
